@@ -4,11 +4,12 @@
 	real*8  ke(maxn)
 	integer indx(maxn)
         integer nevent
+        integer outzero
         integer pjmnum, tgmnum  ! proj. target mass number
         record /ptcl/ pj, tg, plab
         common /Zotherc/ pj, tg, plab, ke, wzmin, wzmax, 
      *    trackl,
-     *    indx, nevent,
+     *    indx, nevent, outzero,
      *    pjmnum, tgmnum
 
 
